<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namibia)',
        'af_ZA' => 'afrikaans (Sudafrica)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Ghana)',
        'am' => 'amarico',
        'am_ET' => 'amarico (Etiopia)',
        'ar' => 'arabo',
        'ar_001' => 'arabo (Mondo)',
        'ar_AE' => 'arabo (Emirati Arabi Uniti)',
        'ar_BH' => 'arabo (Bahrein)',
        'ar_DJ' => 'arabo (Gibuti)',
        'ar_DZ' => 'arabo (Algeria)',
        'ar_EG' => 'arabo (Egitto)',
        'ar_EH' => 'arabo (Sahara occidentale)',
        'ar_ER' => 'arabo (Eritrea)',
        'ar_IL' => 'arabo (Israele)',
        'ar_IQ' => 'arabo (Iraq)',
        'ar_JO' => 'arabo (Giordania)',
        'ar_KM' => 'arabo (Comore)',
        'ar_KW' => 'arabo (Kuwait)',
        'ar_LB' => 'arabo (Libano)',
        'ar_LY' => 'arabo (Libia)',
        'ar_MA' => 'arabo (Marocco)',
        'ar_MR' => 'arabo (Mauritania)',
        'ar_OM' => 'arabo (Oman)',
        'ar_PS' => 'arabo (Territori palestinesi)',
        'ar_QA' => 'arabo (Qatar)',
        'ar_SA' => 'arabo (Arabia Saudita)',
        'ar_SD' => 'arabo (Sudan)',
        'ar_SO' => 'arabo (Somalia)',
        'ar_SS' => 'arabo (Sud Sudan)',
        'ar_SY' => 'arabo (Siria)',
        'ar_TD' => 'arabo (Ciad)',
        'ar_TN' => 'arabo (Tunisia)',
        'ar_YE' => 'arabo (Yemen)',
        'as' => 'assamese',
        'as_IN' => 'assamese (India)',
        'az' => 'azerbaigiano',
        'az_AZ' => 'azerbaigiano (Azerbaigian)',
        'az_Cyrl' => 'azerbaigiano (cirillico)',
        'az_Cyrl_AZ' => 'azerbaigiano (cirillico, Azerbaigian)',
        'az_Latn' => 'azerbaigiano (latino)',
        'az_Latn_AZ' => 'azerbaigiano (latino, Azerbaigian)',
        'be' => 'bielorusso',
        'be_BY' => 'bielorusso (Bielorussia)',
        'bg' => 'bulgaro',
        'bg_BG' => 'bulgaro (Bulgaria)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengalese',
        'bn_BD' => 'bengalese (Bangladesh)',
        'bn_IN' => 'bengalese (India)',
        'bo' => 'tibetano',
        'bo_CN' => 'tibetano (Cina)',
        'bo_IN' => 'tibetano (India)',
        'br' => 'bretone',
        'br_FR' => 'bretone (Francia)',
        'bs' => 'bosniaco',
        'bs_BA' => 'bosniaco (Bosnia ed Erzegovina)',
        'bs_Cyrl' => 'bosniaco (cirillico)',
        'bs_Cyrl_BA' => 'bosniaco (cirillico, Bosnia ed Erzegovina)',
        'bs_Latn' => 'bosniaco (latino)',
        'bs_Latn_BA' => 'bosniaco (latino, Bosnia ed Erzegovina)',
        'ca' => 'catalano',
        'ca_AD' => 'catalano (Andorra)',
        'ca_ES' => 'catalano (Spagna)',
        'ca_FR' => 'catalano (Francia)',
        'ca_IT' => 'catalano (Italia)',
        'ce' => 'ceceno',
        'ce_RU' => 'ceceno (Russia)',
        'cs' => 'ceco',
        'cs_CZ' => 'ceco (Cechia)',
        'cv' => 'ciuvascio',
        'cv_RU' => 'ciuvascio (Russia)',
        'cy' => 'gallese',
        'cy_GB' => 'gallese (Regno Unito)',
        'da' => 'danese',
        'da_DK' => 'danese (Danimarca)',
        'da_GL' => 'danese (Groenlandia)',
        'de' => 'tedesco',
        'de_AT' => 'tedesco (Austria)',
        'de_BE' => 'tedesco (Belgio)',
        'de_CH' => 'tedesco (Svizzera)',
        'de_DE' => 'tedesco (Germania)',
        'de_IT' => 'tedesco (Italia)',
        'de_LI' => 'tedesco (Liechtenstein)',
        'de_LU' => 'tedesco (Lussemburgo)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhutan)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Ghana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'greco',
        'el_CY' => 'greco (Cipro)',
        'el_GR' => 'greco (Grecia)',
        'en' => 'inglese',
        'en_001' => 'inglese (Mondo)',
        'en_150' => 'inglese (Europa)',
        'en_AE' => 'inglese (Emirati Arabi Uniti)',
        'en_AG' => 'inglese (Antigua e Barbuda)',
        'en_AI' => 'inglese (Anguilla)',
        'en_AS' => 'inglese (Samoa americane)',
        'en_AT' => 'inglese (Austria)',
        'en_AU' => 'inglese (Australia)',
        'en_BB' => 'inglese (Barbados)',
        'en_BE' => 'inglese (Belgio)',
        'en_BI' => 'inglese (Burundi)',
        'en_BM' => 'inglese (Bermuda)',
        'en_BS' => 'inglese (Bahamas)',
        'en_BW' => 'inglese (Botswana)',
        'en_BZ' => 'inglese (Belize)',
        'en_CA' => 'inglese (Canada)',
        'en_CC' => 'inglese (Isole Cocos [Keeling])',
        'en_CH' => 'inglese (Svizzera)',
        'en_CK' => 'inglese (Isole Cook)',
        'en_CM' => 'inglese (Camerun)',
        'en_CX' => 'inglese (Isola Christmas)',
        'en_CY' => 'inglese (Cipro)',
        'en_DE' => 'inglese (Germania)',
        'en_DK' => 'inglese (Danimarca)',
        'en_DM' => 'inglese (Dominica)',
        'en_ER' => 'inglese (Eritrea)',
        'en_FI' => 'inglese (Finlandia)',
        'en_FJ' => 'inglese (Figi)',
        'en_FK' => 'inglese (Isole Falkland)',
        'en_FM' => 'inglese (Micronesia)',
        'en_GB' => 'inglese (Regno Unito)',
        'en_GD' => 'inglese (Grenada)',
        'en_GG' => 'inglese (Guernsey)',
        'en_GH' => 'inglese (Ghana)',
        'en_GI' => 'inglese (Gibilterra)',
        'en_GM' => 'inglese (Gambia)',
        'en_GU' => 'inglese (Guam)',
        'en_GY' => 'inglese (Guyana)',
        'en_HK' => 'inglese (RAS di Hong Kong)',
        'en_IE' => 'inglese (Irlanda)',
        'en_IL' => 'inglese (Israele)',
        'en_IM' => 'inglese (Isola di Man)',
        'en_IN' => 'inglese (India)',
        'en_IO' => 'inglese (Territorio britannico dell’Oceano Indiano)',
        'en_JE' => 'inglese (Jersey)',
        'en_JM' => 'inglese (Giamaica)',
        'en_KE' => 'inglese (Kenya)',
        'en_KI' => 'inglese (Kiribati)',
        'en_KN' => 'inglese (Saint Kitts e Nevis)',
        'en_KY' => 'inglese (Isole Cayman)',
        'en_LC' => 'inglese (Saint Lucia)',
        'en_LR' => 'inglese (Liberia)',
        'en_LS' => 'inglese (Lesotho)',
        'en_MG' => 'inglese (Madagascar)',
        'en_MH' => 'inglese (Isole Marshall)',
        'en_MO' => 'inglese (RAS di Macao)',
        'en_MP' => 'inglese (Isole Marianne settentrionali)',
        'en_MS' => 'inglese (Montserrat)',
        'en_MT' => 'inglese (Malta)',
        'en_MU' => 'inglese (Mauritius)',
        'en_MV' => 'inglese (Maldive)',
        'en_MW' => 'inglese (Malawi)',
        'en_MY' => 'inglese (Malaysia)',
        'en_NA' => 'inglese (Namibia)',
        'en_NF' => 'inglese (Isola Norfolk)',
        'en_NG' => 'inglese (Nigeria)',
        'en_NL' => 'inglese (Paesi Bassi)',
        'en_NR' => 'inglese (Nauru)',
        'en_NU' => 'inglese (Niue)',
        'en_NZ' => 'inglese (Nuova Zelanda)',
        'en_PG' => 'inglese (Papua Nuova Guinea)',
        'en_PH' => 'inglese (Filippine)',
        'en_PK' => 'inglese (Pakistan)',
        'en_PN' => 'inglese (Isole Pitcairn)',
        'en_PR' => 'inglese (Portorico)',
        'en_PW' => 'inglese (Palau)',
        'en_RW' => 'inglese (Ruanda)',
        'en_SB' => 'inglese (Isole Salomone)',
        'en_SC' => 'inglese (Seychelles)',
        'en_SD' => 'inglese (Sudan)',
        'en_SE' => 'inglese (Svezia)',
        'en_SG' => 'inglese (Singapore)',
        'en_SH' => 'inglese (Sant’Elena)',
        'en_SI' => 'inglese (Slovenia)',
        'en_SL' => 'inglese (Sierra Leone)',
        'en_SS' => 'inglese (Sud Sudan)',
        'en_SX' => 'inglese (Sint Maarten)',
        'en_SZ' => 'inglese (eSwatini)',
        'en_TC' => 'inglese (Isole Turks e Caicos)',
        'en_TK' => 'inglese (Tokelau)',
        'en_TO' => 'inglese (Tonga)',
        'en_TT' => 'inglese (Trinidad e Tobago)',
        'en_TV' => 'inglese (Tuvalu)',
        'en_TZ' => 'inglese (Tanzania)',
        'en_UG' => 'inglese (Uganda)',
        'en_UM' => 'inglese (Isole Minori Esterne degli Stati Uniti)',
        'en_US' => 'inglese (Stati Uniti)',
        'en_VC' => 'inglese (Saint Vincent e Grenadine)',
        'en_VG' => 'inglese (Isole Vergini Britanniche)',
        'en_VI' => 'inglese (Isole Vergini Americane)',
        'en_VU' => 'inglese (Vanuatu)',
        'en_WS' => 'inglese (Samoa)',
        'en_ZA' => 'inglese (Sudafrica)',
        'en_ZM' => 'inglese (Zambia)',
        'en_ZW' => 'inglese (Zimbabwe)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (Mondo)',
        'es' => 'spagnolo',
        'es_419' => 'spagnolo (America Latina)',
        'es_AR' => 'spagnolo (Argentina)',
        'es_BO' => 'spagnolo (Bolivia)',
        'es_BR' => 'spagnolo (Brasile)',
        'es_BZ' => 'spagnolo (Belize)',
        'es_CL' => 'spagnolo (Cile)',
        'es_CO' => 'spagnolo (Colombia)',
        'es_CR' => 'spagnolo (Costa Rica)',
        'es_CU' => 'spagnolo (Cuba)',
        'es_DO' => 'spagnolo (Repubblica Dominicana)',
        'es_EC' => 'spagnolo (Ecuador)',
        'es_ES' => 'spagnolo (Spagna)',
        'es_GQ' => 'spagnolo (Guinea Equatoriale)',
        'es_GT' => 'spagnolo (Guatemala)',
        'es_HN' => 'spagnolo (Honduras)',
        'es_MX' => 'spagnolo (Messico)',
        'es_NI' => 'spagnolo (Nicaragua)',
        'es_PA' => 'spagnolo (Panama)',
        'es_PE' => 'spagnolo (Perù)',
        'es_PH' => 'spagnolo (Filippine)',
        'es_PR' => 'spagnolo (Portorico)',
        'es_PY' => 'spagnolo (Paraguay)',
        'es_SV' => 'spagnolo (El Salvador)',
        'es_US' => 'spagnolo (Stati Uniti)',
        'es_UY' => 'spagnolo (Uruguay)',
        'es_VE' => 'spagnolo (Venezuela)',
        'et' => 'estone',
        'et_EE' => 'estone (Estonia)',
        'eu' => 'basco',
        'eu_ES' => 'basco (Spagna)',
        'fa' => 'persiano',
        'fa_AF' => 'persiano (Afghanistan)',
        'fa_IR' => 'persiano (Iran)',
        'ff' => 'fulah',
        'ff_Adlm' => 'fulah (adlam)',
        'ff_Adlm_BF' => 'fulah (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fulah (adlam, Camerun)',
        'ff_Adlm_GH' => 'fulah (adlam, Ghana)',
        'ff_Adlm_GM' => 'fulah (adlam, Gambia)',
        'ff_Adlm_GN' => 'fulah (adlam, Guinea)',
        'ff_Adlm_GW' => 'fulah (adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'fulah (adlam, Liberia)',
        'ff_Adlm_MR' => 'fulah (adlam, Mauritania)',
        'ff_Adlm_NE' => 'fulah (adlam, Niger)',
        'ff_Adlm_NG' => 'fulah (adlam, Nigeria)',
        'ff_Adlm_SL' => 'fulah (adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'fulah (adlam, Senegal)',
        'ff_CM' => 'fulah (Camerun)',
        'ff_GN' => 'fulah (Guinea)',
        'ff_Latn' => 'fulah (latino)',
        'ff_Latn_BF' => 'fulah (latino, Burkina Faso)',
        'ff_Latn_CM' => 'fulah (latino, Camerun)',
        'ff_Latn_GH' => 'fulah (latino, Ghana)',
        'ff_Latn_GM' => 'fulah (latino, Gambia)',
        'ff_Latn_GN' => 'fulah (latino, Guinea)',
        'ff_Latn_GW' => 'fulah (latino, Guinea-Bissau)',
        'ff_Latn_LR' => 'fulah (latino, Liberia)',
        'ff_Latn_MR' => 'fulah (latino, Mauritania)',
        'ff_Latn_NE' => 'fulah (latino, Niger)',
        'ff_Latn_NG' => 'fulah (latino, Nigeria)',
        'ff_Latn_SL' => 'fulah (latino, Sierra Leone)',
        'ff_Latn_SN' => 'fulah (latino, Senegal)',
        'ff_MR' => 'fulah (Mauritania)',
        'ff_SN' => 'fulah (Senegal)',
        'fi' => 'finlandese',
        'fi_FI' => 'finlandese (Finlandia)',
        'fo' => 'faroese',
        'fo_DK' => 'faroese (Danimarca)',
        'fo_FO' => 'faroese (Isole Fær Øer)',
        'fr' => 'francese',
        'fr_BE' => 'francese (Belgio)',
        'fr_BF' => 'francese (Burkina Faso)',
        'fr_BI' => 'francese (Burundi)',
        'fr_BJ' => 'francese (Benin)',
        'fr_BL' => 'francese (Saint-Barthélemy)',
        'fr_CA' => 'francese (Canada)',
        'fr_CD' => 'francese (Congo - Kinshasa)',
        'fr_CF' => 'francese (Repubblica Centrafricana)',
        'fr_CG' => 'francese (Congo-Brazzaville)',
        'fr_CH' => 'francese (Svizzera)',
        'fr_CI' => 'francese (Costa d’Avorio)',
        'fr_CM' => 'francese (Camerun)',
        'fr_DJ' => 'francese (Gibuti)',
        'fr_DZ' => 'francese (Algeria)',
        'fr_FR' => 'francese (Francia)',
        'fr_GA' => 'francese (Gabon)',
        'fr_GF' => 'francese (Guyana Francese)',
        'fr_GN' => 'francese (Guinea)',
        'fr_GP' => 'francese (Guadalupa)',
        'fr_GQ' => 'francese (Guinea Equatoriale)',
        'fr_HT' => 'francese (Haiti)',
        'fr_KM' => 'francese (Comore)',
        'fr_LU' => 'francese (Lussemburgo)',
        'fr_MA' => 'francese (Marocco)',
        'fr_MC' => 'francese (Monaco)',
        'fr_MF' => 'francese (Saint Martin)',
        'fr_MG' => 'francese (Madagascar)',
        'fr_ML' => 'francese (Mali)',
        'fr_MQ' => 'francese (Martinica)',
        'fr_MR' => 'francese (Mauritania)',
        'fr_MU' => 'francese (Mauritius)',
        'fr_NC' => 'francese (Nuova Caledonia)',
        'fr_NE' => 'francese (Niger)',
        'fr_PF' => 'francese (Polinesia francese)',
        'fr_PM' => 'francese (Saint-Pierre e Miquelon)',
        'fr_RE' => 'francese (Riunione)',
        'fr_RW' => 'francese (Ruanda)',
        'fr_SC' => 'francese (Seychelles)',
        'fr_SN' => 'francese (Senegal)',
        'fr_SY' => 'francese (Siria)',
        'fr_TD' => 'francese (Ciad)',
        'fr_TG' => 'francese (Togo)',
        'fr_TN' => 'francese (Tunisia)',
        'fr_VU' => 'francese (Vanuatu)',
        'fr_WF' => 'francese (Wallis e Futuna)',
        'fr_YT' => 'francese (Mayotte)',
        'fy' => 'frisone occidentale',
        'fy_NL' => 'frisone occidentale (Paesi Bassi)',
        'ga' => 'irlandese',
        'ga_GB' => 'irlandese (Regno Unito)',
        'ga_IE' => 'irlandese (Irlanda)',
        'gd' => 'gaelico scozzese',
        'gd_GB' => 'gaelico scozzese (Regno Unito)',
        'gl' => 'galiziano',
        'gl_ES' => 'galiziano (Spagna)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (India)',
        'gv' => 'mannese',
        'gv_IM' => 'mannese (Isola di Man)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Ghana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigeria)',
        'he' => 'ebraico',
        'he_IL' => 'ebraico (Israele)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (India)',
        'hi_Latn' => 'hindi (latino)',
        'hi_Latn_IN' => 'hindi (latino, India)',
        'hr' => 'croato',
        'hr_BA' => 'croato (Bosnia ed Erzegovina)',
        'hr_HR' => 'croato (Croazia)',
        'hu' => 'ungherese',
        'hu_HU' => 'ungherese (Ungheria)',
        'hy' => 'armeno',
        'hy_AM' => 'armeno (Armenia)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (Mondo)',
        'id' => 'indonesiano',
        'id_ID' => 'indonesiano (Indonesia)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigeria)',
        'ii' => 'sichuan yi',
        'ii_CN' => 'sichuan yi (Cina)',
        'is' => 'islandese',
        'is_IS' => 'islandese (Islanda)',
        'it' => 'italiano',
        'it_CH' => 'italiano (Svizzera)',
        'it_IT' => 'italiano (Italia)',
        'it_SM' => 'italiano (San Marino)',
        'it_VA' => 'italiano (Città del Vaticano)',
        'ja' => 'giapponese',
        'ja_JP' => 'giapponese (Giappone)',
        'jv' => 'giavanese',
        'jv_ID' => 'giavanese (Indonesia)',
        'ka' => 'georgiano',
        'ka_GE' => 'georgiano (Georgia)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Kenya)',
        'kk' => 'kazako',
        'kk_KZ' => 'kazako (Kazakistan)',
        'kl' => 'groenlandese',
        'kl_GL' => 'groenlandese (Groenlandia)',
        'km' => 'khmer',
        'km_KH' => 'khmer (Cambogia)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (India)',
        'ko' => 'coreano',
        'ko_KP' => 'coreano (Corea del Nord)',
        'ko_KR' => 'coreano (Corea del Sud)',
        'ks' => 'kashmiri',
        'ks_Arab' => 'kashmiri (arabo)',
        'ks_Arab_IN' => 'kashmiri (arabo, India)',
        'ks_Deva' => 'kashmiri (devanagari)',
        'ks_Deva_IN' => 'kashmiri (devanagari, India)',
        'ks_IN' => 'kashmiri (India)',
        'ku' => 'curdo',
        'ku_TR' => 'curdo (Turchia)',
        'kw' => 'cornico',
        'kw_GB' => 'cornico (Regno Unito)',
        'ky' => 'kirghiso',
        'ky_KG' => 'kirghiso (Kirghizistan)',
        'lb' => 'lussemburghese',
        'lb_LU' => 'lussemburghese (Lussemburgo)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Congo - Kinshasa)',
        'ln_CF' => 'lingala (Repubblica Centrafricana)',
        'ln_CG' => 'lingala (Congo-Brazzaville)',
        'lo' => 'lao',
        'lo_LA' => 'lao (Laos)',
        'lt' => 'lituano',
        'lt_LT' => 'lituano (Lituania)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Congo - Kinshasa)',
        'lv' => 'lettone',
        'lv_LV' => 'lettone (Lettonia)',
        'mg' => 'malgascio',
        'mg_MG' => 'malgascio (Madagascar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Nuova Zelanda)',
        'mk' => 'macedone',
        'mk_MK' => 'macedone (Macedonia del Nord)',
        'ml' => 'malayalam',
        'ml_IN' => 'malayalam (India)',
        'mn' => 'mongolo',
        'mn_MN' => 'mongolo (Mongolia)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (India)',
        'ms' => 'malese',
        'ms_BN' => 'malese (Brunei)',
        'ms_ID' => 'malese (Indonesia)',
        'ms_MY' => 'malese (Malaysia)',
        'ms_SG' => 'malese (Singapore)',
        'mt' => 'maltese',
        'mt_MT' => 'maltese (Malta)',
        'my' => 'birmano',
        'my_MM' => 'birmano (Myanmar [Birmania])',
        'nb' => 'norvegese bokmål',
        'nb_NO' => 'norvegese bokmål (Norvegia)',
        'nb_SJ' => 'norvegese bokmål (Svalbard e Jan Mayen)',
        'nd' => 'ndebele del nord',
        'nd_ZW' => 'ndebele del nord (Zimbabwe)',
        'ne' => 'nepalese',
        'ne_IN' => 'nepalese (India)',
        'ne_NP' => 'nepalese (Nepal)',
        'nl' => 'olandese',
        'nl_AW' => 'olandese (Aruba)',
        'nl_BE' => 'olandese (Belgio)',
        'nl_BQ' => 'olandese (Caraibi olandesi)',
        'nl_CW' => 'olandese (Curaçao)',
        'nl_NL' => 'olandese (Paesi Bassi)',
        'nl_SR' => 'olandese (Suriname)',
        'nl_SX' => 'olandese (Sint Maarten)',
        'nn' => 'norvegese nynorsk',
        'nn_NO' => 'norvegese nynorsk (Norvegia)',
        'no' => 'norvegese',
        'no_NO' => 'norvegese (Norvegia)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiopia)',
        'om_KE' => 'oromo (Kenya)',
        'or' => 'odia',
        'or_IN' => 'odia (India)',
        'os' => 'ossetico',
        'os_GE' => 'ossetico (Georgia)',
        'os_RU' => 'ossetico (Russia)',
        'pa' => 'punjabi',
        'pa_Arab' => 'punjabi (arabo)',
        'pa_Arab_PK' => 'punjabi (arabo, Pakistan)',
        'pa_Guru' => 'punjabi (gurmukhi)',
        'pa_Guru_IN' => 'punjabi (gurmukhi, India)',
        'pa_IN' => 'punjabi (India)',
        'pa_PK' => 'punjabi (Pakistan)',
        'pl' => 'polacco',
        'pl_PL' => 'polacco (Polonia)',
        'ps' => 'pashto',
        'ps_AF' => 'pashto (Afghanistan)',
        'ps_PK' => 'pashto (Pakistan)',
        'pt' => 'portoghese',
        'pt_AO' => 'portoghese (Angola)',
        'pt_BR' => 'portoghese (Brasile)',
        'pt_CH' => 'portoghese (Svizzera)',
        'pt_CV' => 'portoghese (Capo Verde)',
        'pt_GQ' => 'portoghese (Guinea Equatoriale)',
        'pt_GW' => 'portoghese (Guinea-Bissau)',
        'pt_LU' => 'portoghese (Lussemburgo)',
        'pt_MO' => 'portoghese (RAS di Macao)',
        'pt_MZ' => 'portoghese (Mozambico)',
        'pt_PT' => 'portoghese (Portogallo)',
        'pt_ST' => 'portoghese (São Tomé e Príncipe)',
        'pt_TL' => 'portoghese (Timor Est)',
        'qu' => 'quechua',
        'qu_BO' => 'quechua (Bolivia)',
        'qu_EC' => 'quechua (Ecuador)',
        'qu_PE' => 'quechua (Perù)',
        'rm' => 'romancio',
        'rm_CH' => 'romancio (Svizzera)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'rumeno',
        'ro_MD' => 'rumeno (Moldavia)',
        'ro_RO' => 'rumeno (Romania)',
        'ru' => 'russo',
        'ru_BY' => 'russo (Bielorussia)',
        'ru_KG' => 'russo (Kirghizistan)',
        'ru_KZ' => 'russo (Kazakistan)',
        'ru_MD' => 'russo (Moldavia)',
        'ru_RU' => 'russo (Russia)',
        'ru_UA' => 'russo (Ucraina)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Ruanda)',
        'sa' => 'sanscrito',
        'sa_IN' => 'sanscrito (India)',
        'sc' => 'sardo',
        'sc_IT' => 'sardo (Italia)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (arabo)',
        'sd_Arab_PK' => 'sindhi (arabo, Pakistan)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, India)',
        'sd_IN' => 'sindhi (India)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'sami del nord',
        'se_FI' => 'sami del nord (Finlandia)',
        'se_NO' => 'sami del nord (Norvegia)',
        'se_SE' => 'sami del nord (Svezia)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Repubblica Centrafricana)',
        'sh' => 'serbo-croato',
        'sh_BA' => 'serbo-croato (Bosnia ed Erzegovina)',
        'si' => 'singalese',
        'si_LK' => 'singalese (Sri Lanka)',
        'sk' => 'slovacco',
        'sk_SK' => 'slovacco (Slovacchia)',
        'sl' => 'sloveno',
        'sl_SI' => 'sloveno (Slovenia)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Zimbabwe)',
        'so' => 'somalo',
        'so_DJ' => 'somalo (Gibuti)',
        'so_ET' => 'somalo (Etiopia)',
        'so_KE' => 'somalo (Kenya)',
        'so_SO' => 'somalo (Somalia)',
        'sq' => 'albanese',
        'sq_AL' => 'albanese (Albania)',
        'sq_MK' => 'albanese (Macedonia del Nord)',
        'sr' => 'serbo',
        'sr_BA' => 'serbo (Bosnia ed Erzegovina)',
        'sr_Cyrl' => 'serbo (cirillico)',
        'sr_Cyrl_BA' => 'serbo (cirillico, Bosnia ed Erzegovina)',
        'sr_Cyrl_ME' => 'serbo (cirillico, Montenegro)',
        'sr_Cyrl_RS' => 'serbo (cirillico, Serbia)',
        'sr_Latn' => 'serbo (latino)',
        'sr_Latn_BA' => 'serbo (latino, Bosnia ed Erzegovina)',
        'sr_Latn_ME' => 'serbo (latino, Montenegro)',
        'sr_Latn_RS' => 'serbo (latino, Serbia)',
        'sr_ME' => 'serbo (Montenegro)',
        'sr_RS' => 'serbo (Serbia)',
        'su' => 'sundanese',
        'su_ID' => 'sundanese (Indonesia)',
        'su_Latn' => 'sundanese (latino)',
        'su_Latn_ID' => 'sundanese (latino, Indonesia)',
        'sv' => 'svedese',
        'sv_AX' => 'svedese (Isole Åland)',
        'sv_FI' => 'svedese (Finlandia)',
        'sv_SE' => 'svedese (Svezia)',
        'sw' => 'swahili',
        'sw_CD' => 'swahili (Congo - Kinshasa)',
        'sw_KE' => 'swahili (Kenya)',
        'sw_TZ' => 'swahili (Tanzania)',
        'sw_UG' => 'swahili (Uganda)',
        'ta' => 'tamil',
        'ta_IN' => 'tamil (India)',
        'ta_LK' => 'tamil (Sri Lanka)',
        'ta_MY' => 'tamil (Malaysia)',
        'ta_SG' => 'tamil (Singapore)',
        'te' => 'telugu',
        'te_IN' => 'telugu (India)',
        'tg' => 'tagico',
        'tg_TJ' => 'tagico (Tagikistan)',
        'th' => 'thailandese',
        'th_TH' => 'thailandese (Thailandia)',
        'ti' => 'tigrino',
        'ti_ER' => 'tigrino (Eritrea)',
        'ti_ET' => 'tigrino (Etiopia)',
        'tk' => 'turcomanno',
        'tk_TM' => 'turcomanno (Turkmenistan)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Filippine)',
        'to' => 'tongano',
        'to_TO' => 'tongano (Tonga)',
        'tr' => 'turco',
        'tr_CY' => 'turco (Cipro)',
        'tr_TR' => 'turco (Turchia)',
        'tt' => 'tataro',
        'tt_RU' => 'tataro (Russia)',
        'ug' => 'uiguro',
        'ug_CN' => 'uiguro (Cina)',
        'uk' => 'ucraino',
        'uk_UA' => 'ucraino (Ucraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (India)',
        'ur_PK' => 'urdu (Pakistan)',
        'uz' => 'uzbeco',
        'uz_AF' => 'uzbeco (Afghanistan)',
        'uz_Arab' => 'uzbeco (arabo)',
        'uz_Arab_AF' => 'uzbeco (arabo, Afghanistan)',
        'uz_Cyrl' => 'uzbeco (cirillico)',
        'uz_Cyrl_UZ' => 'uzbeco (cirillico, Uzbekistan)',
        'uz_Latn' => 'uzbeco (latino)',
        'uz_Latn_UZ' => 'uzbeco (latino, Uzbekistan)',
        'uz_UZ' => 'uzbeco (Uzbekistan)',
        'vi' => 'vietnamita',
        'vi_VN' => 'vietnamita (Vietnam)',
        'wo' => 'wolof',
        'wo_SN' => 'wolof (Senegal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (Sudafrica)',
        'yi' => 'yiddish',
        'yi_001' => 'yiddish (Mondo)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Benin)',
        'yo_NG' => 'yoruba (Nigeria)',
        'zh' => 'cinese',
        'zh_CN' => 'cinese (Cina)',
        'zh_HK' => 'cinese (RAS di Hong Kong)',
        'zh_Hans' => 'cinese (semplificato)',
        'zh_Hans_CN' => 'cinese (semplificato, Cina)',
        'zh_Hans_HK' => 'cinese (semplificato, RAS di Hong Kong)',
        'zh_Hans_MO' => 'cinese (semplificato, RAS di Macao)',
        'zh_Hans_SG' => 'cinese (semplificato, Singapore)',
        'zh_Hant' => 'cinese (tradizionale)',
        'zh_Hant_HK' => 'cinese (tradizionale, RAS di Hong Kong)',
        'zh_Hant_MO' => 'cinese (tradizionale, RAS di Macao)',
        'zh_Hant_TW' => 'cinese (tradizionale, Taiwan)',
        'zh_MO' => 'cinese (RAS di Macao)',
        'zh_SG' => 'cinese (Singapore)',
        'zh_TW' => 'cinese (Taiwan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Sudafrica)',
    ],
];
